==> video-android-2.0.1-sources.jar: com/twilio/video/AspectRatio.java <==
/*
 * Copyright (C) 2017 Twilio, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.twilio.video;

/**
 *  Rational aspect ratio represented as numerator:denominator.
 *  For x:y aspect ratio you can set numerator to x and denominator to y.
 */
public class AspectRatio {
    /** Pre-defined aspect ratio 4:3. */
    public static final AspectRatio ASPECT_RATIO_4_3 = new AspectRatio(4, 3);

    /** Pre-defined aspect ratio 16:9. */
    public static final AspectRatio ASPECT_RATIO_16_9 = new AspectRatio(16, 9);

    /** Pre-defined aspect ratio 11:9. */
    public static final AspectRatio ASPECT_RATIO_11_9 = new AspectRatio(11, 9);

    public final int numerator;
    public final int denominator;

    public AspectRatio(int numerator, int denominator) {
        this.numerator = numerator;
        this.denominator = denominator;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        AspectRatio that = (AspectRatio) o;

        if (numerator != that.numerator) return false;
        return denominator == that.denominator;

    }

    @Override
    public int hashCode() {
        int result = numerator;
        result = 31 * result + denominator;
        return result;
    }
}

==> video-android-2.1.1-sources.jar: com/twilio/video/AspectRatio.java <==
/*
 * Copyright (C) 2017 Twilio, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.twilio.video;

/**
 * Rational aspect ratio represented as numerator:denominator. For x:y aspect ratio you can set
 * numerator to x and denominator to y.
 */
public class AspectRatio {
    /** Pre-defined aspect ratio 4:3. */
    public static final AspectRatio ASPECT_RATIO_4_3 = new AspectRatio(4, 3);

    /** Pre-defined aspect ratio 16:9. */
    public static final AspectRatio ASPECT_RATIO_16_9 = new AspectRatio(16, 9);

    /** Pre-defined aspect ratio 11:9. */
    public static final AspectRatio ASPECT_RATIO_11_9 = new AspectRatio(11, 9);

    public final int numerator;
    public final int denominator;

    public AspectRatio(int numerator, int denominator) {
        this.numerator = numerator;
        this.denominator = denominator;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        AspectRatio that = (AspectRatio) o;

        if (numerator != that.numerator) return false;
        return denominator == that.denominator;
    }

    @Override
    public int hashCode() {
        int result = numerator;
        result = 31 * result + denominator;
        return result;
    }
}
